@@ -76,7 +76,8 @@ def run(cfg: config.Loader, logger: logging.Logger, uri: str, **kwargs) -> str:
     useful in particular.
     """
 
-    from . import run_local_task, RunFailed, DownloadFailed, Terminated, error_json
+    from .error import RunFailed, DownloadFailed, Terminated, error_json
+    from .task import run_local_task
     from .. import parse_document, values_from_json, values_to_json, Walker
 
     gen = _downloader(cfg, uri)
@@ -209,7 +210,10 @@ def awscli_downloader(
             logger.getChild("awscli_downloader").info("loaded host AWS credentials")
         else:
             logger.getChild("awscli_downloader").info(
-                "no AWS credentials available via host awscli/boto3; if needed, configure them and set [download_awscli] host_credentials=true. (On EC2: awscli might still assume role from instance metadata service.)"
+                "no AWS credentials available via host awscli/boto3; if needed, "
+                "configure them and set [download_awscli] host_credentials=true. "
+                "(On EC2: awscli might still assume role from instance metadata "
+                "service.)"
             )
 
         wdl = r"""
