@@ -208,7 +208,7 @@ class TestTasks(unittest.TestCase):
         self.assertEqual(task.command.parts[1].eval(WDL.Env.Bindings().bind('s', foobar)).value, 'foo, bar')
         foobar = WDL.Value.Array(WDL.Type.String(), [])
         self.assertEqual(task.command.parts[1].eval(WDL.Env.Bindings().bind('s', foobar)).value, '')
-        with self.assertRaises(WDL.Error.StaticTypeMismatch):
+        with self.assertRaises(WDL.Error.IncompatibleOperand):
             task = WDL.parse_tasks("""
             task wc {
                 input {
@@ -490,9 +490,14 @@ class TestTypes(unittest.TestCase):
         workflow unify {
             String s
             File? f2
+            Array[Int] a1 = [1]
+            Array[Int?]? a2 = []
+            Array[Pair[String,String]] ap = [(0,1),(2,3)]
+            Array[Map[String,String]] am = [{ "a": 0, "b": 1 }, { "a": "x", "b": "y" }, { 1: 2, 3: 4 }]
 
             output {
                 Array[File?] a = [s, f2]
+                Array[Array[Int?]?] a3 = [a1, a2]
                 Map[String, File?] m = { "foo": s, "bar": f2 }
                 Map[Float, File?] m2 = { 1: s, 2.0: f2 }
             }
@@ -500,6 +505,14 @@ class TestTypes(unittest.TestCase):
         """)
         doc.typecheck()
 
+        with self.assertRaises(WDL.Error.ValidationError):
+            doc = WDL.parse_document("""
+            workflow unify {
+                Array[Pair[String,String]] bogus = [("a","b"), ("c",("d","e"))]
+            }
+            """)
+            doc.typecheck()
+
 class TestDoc(unittest.TestCase):
     def test_count_foo(self):
         doc = r"""#foo
